//
// snappy-remote - Tool to download work with remote snappy instances.
//
// Copyright (c) 2014 Canonical Ltd.
//
// Written by Sergio Schvezov <sergio.schvezov@canonical.com>
//
package main

import (
	"fmt"
	"os"
	"path/filepath"
	"strings"
)

// This program is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License version 3, as published
// by the Free Software Foundation.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranties of
// MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
// PURPOSE.  See the GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program.  If not, see <http://www.gnu.org/licenses/>.

type InstallCmd struct {
	Args struct {
		Packages []string `description:"list of packages either remote or local to install" value-name:"packages"`
	} `positional-args:"yes" required:"yes"`
}

var installCmd InstallCmd

func init() {
	parser.AddCommand("install",
		"Install a snappy package on a remote system from disk or the store",
		"",
		&installCmd)
}

func (installCmd *InstallCmd) Execute(args []string) error {
	if err := setup(); err != nil {
		return err
	}

	fmt.Println("=======================================================")
	fmt.Println()

	for _, pkg := range installCmd.Args.Packages {
		const installCmdBase = "sudo snappy install"
		var installCmd string

		if strings.HasSuffix(pkg, ".snap") {

			if _, err := os.Stat(pkg); err != nil {
				return err
			}

			fmt.Println("Installing", pkg, "from local environment")
			src := pkg
			pkg = filepath.Join("/tmp", filepath.Base(pkg))
			if err := globalArgs.remote.Copy(src, pkg); err != nil {
				return err
			}
			defer globalArgs.remote.Run(fmt.Sprintf("rm %s", pkg))
			installCmd = fmt.Sprintf("%s --allow-unauthenticated %s", installCmdBase, pkg)
		} else {
			fmt.Println("Installing", pkg, "from the store")
			installCmd = fmt.Sprintf("%s %s", installCmdBase, pkg)
		}

		if err := globalArgs.remote.Run(installCmd); err != nil {
			return err
		}

		fmt.Println("=======================================================")
		fmt.Println()
	}

	return nil
}
